import { useState, useRef, useEffect } from "react";
import { COMPANY_NAME, NAVIGATION } from "@/lib/constants";
import { Button } from "@/components/ui/button";
import { Menu, Calendar, PhoneCall, ChevronDown, ChevronUp } from "lucide-react";

export default function SimpleHeader() {
  // Mobile navigation state
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  
  // Desktop dropdown navigation state
  const [activeDropdown, setActiveDropdown] = useState<string | null>(null);
  const dropdownRef = useRef<HTMLDivElement>(null);
  
  // Close dropdown when clicking outside
  useEffect(() => {
    function handleClickOutside(event: MouseEvent) {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target as Node)) {
        setActiveDropdown(null);
      }
    }
    
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, []);
  
  // Toggle dropdown visibility
  const toggleDropdown = (itemName: string) => {
    setActiveDropdown(prevState => prevState === itemName ? null : itemName);
  };
  
  return (
    <header className="border-b">
      <div className="bg-gradient-to-r from-primary/5 via-primary/10 to-primary/5">
        <div className="container mx-auto px-4 h-12 flex items-center justify-end gap-4">
          <a href="/consultation" className="no-underline">
            <Button
              size="sm"
              variant="default"
              className="text-white hover:text-white hover:bg-primary/90 transition-all duration-300 font-medium flex items-center gap-2 rounded-full px-4"
            >
              <Calendar className="h-4 w-4" />
              Book Free Appointment
            </Button>
          </a>
          <a href="/contact" className="no-underline">
            <Button
              size="sm"
              variant="ghost"
              className="text-primary hover:text-primary/80 hover:bg-primary/10 transition-all duration-300 font-medium flex items-center gap-2 rounded-full px-4"
            >
              <PhoneCall className="h-4 w-4" />
              Get In Touch
            </Button>
          </a>
        </div>
      </div>
      <nav className="container mx-auto px-4 h-16 flex items-center justify-between">
        <a href="/" className="no-underline">
          <picture>
            <source srcSet="/images/bjmckenna-logo.webp" type="image/webp" />
            <img 
              src="/images/bjmckenna-logo.jpg" 
              alt={COMPANY_NAME} 
              className="h-11 sm:h-12 w-auto"
            />
          </picture>
        </a>

        {/* Desktop Navigation - Click-based dropdowns */}
        <div ref={dropdownRef} className="hidden md:flex items-center gap-6">
          {NAVIGATION.map((item) => (
            <div key={item.name} className="relative">
              {item.children && item.children.length > 0 ? (
                // Menu item with dropdown
                <>
                  <Button 
                    variant="ghost"
                    className="font-medium flex items-center gap-1"
                    onClick={() => toggleDropdown(item.name)}
                    aria-expanded={activeDropdown === item.name}
                    aria-controls={`dropdown-${item.name}`}
                  >
                    <span>{item.name}</span>
                    {activeDropdown === item.name ? (
                      <ChevronUp className="h-4 w-4" />
                    ) : (
                      <ChevronDown className="h-4 w-4" />
                    )}
                  </Button>
                  
                  {/* Dropdown menu */}
                  {activeDropdown === item.name && (
                    <div 
                      id={`dropdown-${item.name}`}
                      className="absolute top-full left-0 mt-2 w-60 bg-white rounded-md shadow-lg border border-gray-200 py-2 z-50"
                    >
                      {item.children.map((child) => (
                        <a 
                          key={child.href} 
                          href={child.href}
                          className="block px-4 py-2 text-sm text-gray-700 hover:bg-gray-100 no-underline"
                        >
                          {child.name}
                        </a>
                      ))}
                    </div>
                  )}
                </>
              ) : (
                // Single menu item with no dropdown
                <a href={item.href} className="no-underline">
                  <Button 
                    variant="ghost"
                    className="font-medium"
                  >
                    {item.name}
                  </Button>
                </a>
              )}
            </div>
          ))}
        </div>

        {/* Mobile Navigation - simplified */}
        <Button
          variant="ghost"
          size="icon"
          className="md:hidden"
          id="mobile-nav"
          aria-label="Toggle Navigation Menu"
          onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
        >
          <Menu className="h-6 w-6" />
          <span className="sr-only">Navigation</span>
        </Button>
      </nav>
      
      {/* Simple Mobile Menu */}
      <div className={`md:hidden bg-white border-t p-4 ${mobileMenuOpen ? '' : 'hidden'}`}>
        {NAVIGATION.map((item) => (
          <div key={item.name} className="py-2">
            {item.children ? (
              <>
                <h3 className="font-semibold mb-2">{item.name}</h3>
                <div className="pl-4 space-y-1">
                  {item.children.map((child) => (
                    <a 
                      key={child.href} 
                      href={child.href} 
                      className="block py-1 text-sm text-gray-600 hover:text-primary no-underline"
                      onClick={() => setMobileMenuOpen(false)}
                    >
                      {child.name}
                    </a>
                  ))}
                </div>
              </>
            ) : (
              <a 
                href={item.href} 
                className="block font-semibold hover:text-primary no-underline"
                onClick={() => setMobileMenuOpen(false)}
              >
                {item.name}
              </a>
            )}
          </div>
        ))}
      </div>
    </header>
  );
}